"""Example of shallow water wave equation.

This is called Netherlands because it shows a dam with a gap in it and
stylised housed behind it and below the water surface.

"""

######################
# Module imports 
#
from shallow_water import Domain, Reflective_boundary, Dirichlet_boundary,\
     Transmissive_boundary, Time_boundary, Constant_height

from mesh_factory import from_polyfile
from Numeric import array
    

print 'Creating domain'
points, triangles, values = from_polyfile('cornell_room_medres')

#Create shallow water domain
domain = Domain(points, triangles)
    
domain.check_integrity()
domain.default_order = 2
domain.smooth = True
domain.reduction = min  #Looks a lot better on top of steep slopes

print "Number of triangles = ", len(domain)

domain.visualise = False
domain.checkpoint = False
domain.store = True    #Store for visualisation purposes
domain.format = 'sww'   #Native netcdf visualisation format
import sys, os
root, ext = os.path.splitext(sys.argv[0])
if domain.smooth is True:
    s = 'smooth'
else:
    s = 'nonsmooth'        
domain.filename = root + '_' + s

#Set bed-slope and friction
manning = 0.0

print 'Field values'
domain.set_quantity('elevation', values)
domain.set_quantity('friction', manning)


######################
# Boundary conditions
#
print 'Boundaries'
Br = Reflective_boundary(domain)
domain.set_boundary({'exterior': Br})

                  

######################
#Initial condition
#
print 'Initial condition'
E = domain.quantities['elevation'].vertex_values
print max(E)
L = E.copy()
N = len(L)
L[:N/4] += 100
domain.set_quantity('level', L)

#Evolve
for t in domain.evolve(yieldstep = 0.01, finaltime = 1.0):
    domain.write_time()
    

    
